Module key

Module key 

Second Life key (UUID) related types

Structs

AgentKey
represents a Second Life key for an agent (avatar)
ClassifiedKey
represents a Second Life key for a classified ad
EventKey
represents a Second Life key for an event
ExperienceKey
represents a Second Life key for an experience
FriendKey
represents a Second Life key for an agent who is a friend
GroupKey
represents a Second Life key for a group
InventoryFolderKey
represents a Second Life key for an inventory folder
InventoryKey
represents a Second Life key for an inventory item
Key
represents a general Second Life key without any knowledge about the type of entity this represents
ObjectKey
represents a Second Life key for an object
OwnerIsAgentError
error when the owner is an agent while trying to convert an OwnerKey to a GroupKey
OwnerIsGroupError
error when the owner is a group while trying to convert an OwnerKey to an AgentKey
ParcelKey
represents a Second Life key for a parcel
TextureKey
represents a Second Life key for a texture

Enums

OwnerKey
represents s Second Life key for an owner (e.g. of an object)

Constants

COMBAT_LOG_ID
the key used by the Second Life system to send combat logs to the COMBAT_CHANNEL
NULL_KEY
the null key used by Second Life in many places to represent the absence of a key value