Module map

Module map 

Map-related data types

Structs

Distance
represents a Second Life distance in meters
GridCoordinateOffset
an offset between two GridCoordinates
GridCoordinates
Grid coordinates for the position of a region on the map
GridRectangle
represents a rectangle of regions defined by the lower left (minimum coordinates) and upper right (maximum coordinates) corners in GridCoordinates
Location
A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region
MapTileDescriptor
describes a map tile
RegionCoordinates
Region coordinates for the position of something inside a region
RegionName
The name of a region
USBNotecard
An Universal Sailor Buddy (USB) notecard
USBWaypoint
A waypoint in the Universal Sailor Buddy (USB) notecard format
UnconstrainedLocation
A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region, this variant allows out of bounds coordinates (negative and 256 or above for x and y and negative for z)
ZoomLevel
The map tile zoom level for the Second Life main map

Enums

LocationParseError
the possible errors that can occur when parsing a String to a Location
RegionNameError
USBNotecardLoadError
Errors that can happen when an USB notecard is read from a file
ZoomFitError
Errors that can occur when trying to find the correct zoom level to fit regions into an output image of a given size
ZoomLevelError
ZoomLevelParseError

Traits

GridCoordinatesExt
A trait to allow adding methods to Vec<GridCoordinates>
GridRectangleLike
represents a grid rectangle like type (usually one that contains a grid rectangle or one that contains a corner and is of a known size