pub struct Location {
pub region_name: RegionName,
pub x: u8,
pub y: u8,
pub z: u16,
}Expand description
A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region
Fields
region_name: RegionNamethe name of the region of the location
x: u8the x coordinate inside the region
y: u8the y coordinate inside the region
z: u16the z coordinate inside the region
Implementations
Sourceimpl Location
impl Location
Sourcepub const fn region_name(&self) -> &RegionName
pub const fn region_name(&self) -> &RegionName
The region name of this Location
Sourcepub fn as_maps_url(&self) -> String
pub fn as_maps_url(&self) -> String
returns a maps.secondlife.com URL for the Location