pub struct MapTileDescriptor { /* private fields */ }Expand description
describes a map tile
Implementations
Sourceimpl MapTileDescriptor
impl MapTileDescriptor
Sourcepub fn new(zoom_level: ZoomLevel, grid_coordinates: GridCoordinates) -> Self
pub fn new(zoom_level: ZoomLevel, grid_coordinates: GridCoordinates) -> Self
create a new MapTileDescriptor
this will automatically normalize the given GridCoordinates to the
lower left corner of a map tile at that zoom level
Sourcepub const fn zoom_level(&self) -> &ZoomLevel
pub const fn zoom_level(&self) -> &ZoomLevel
the ZoomLevel of the map tile
Sourcepub const fn lower_left_corner(&self) -> &GridCoordinates
pub const fn lower_left_corner(&self) -> &GridCoordinates
the GridCoordinates of the lower left corner of this map tile
Sourcepub fn tile_size_in_pixels(&self) -> u32
pub fn tile_size_in_pixels(&self) -> u32
the size of this map tile in pixels
Sourcepub fn grid_rectangle(&self) -> GridRectangle
pub fn grid_rectangle(&self) -> GridRectangle
the grid rectangle covered by this map tile