UnconstrainedLocation

Struct UnconstrainedLocation 

pub struct UnconstrainedLocation {
    pub region_name: RegionName,
    pub x: i16,
    pub y: i16,
    pub z: i32,
}
A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region, this variant allows out of bounds coordinates (negative and 256 or above for x and y and negative for z)

Fields

region_name: RegionName

the name of the region of the location

x: i16

the x coordinate inside the region

y: i16

the y coordinate inside the region

z: i32

the z coordinate inside the region

Implementations

Source

impl UnconstrainedLocation

pub const fn new(region_name: RegionName, x: i16, y: i16, z: i32) -> Self

Creates a new UnconstrainedLocation

pub const fn region_name(&self) -> &RegionName

The region name of this UnconstrainedLocation

pub const fn x(&self) -> i16

The x coordinate of the UnconstrainedLocation

pub const fn y(&self) -> i16

The y coordinate of the UnconstrainedLocation

pub const fn z(&self) -> i32

The z coordinate of the UnconstrainedLocation