Second Life key (UUID) related types
Structs
- Agent
Key - represents a Second Life key for an agent (avatar)
- Classified
Key - represents a Second Life key for a classified ad
- Event
Key - represents a Second Life key for an event
- Experience
Key - represents a Second Life key for an experience
- Friend
Key - represents a Second Life key for an agent who is a friend
- Group
Key - represents a Second Life key for a group
- Inventory
Folder Key - represents a Second Life key for an inventory folder
- Inventory
Key - represents a Second Life key for an inventory item
- Key
- represents a general Second Life key without any knowledge about the type of entity this represents
- Object
Key - represents a Second Life key for an object
- Owner
IsAgent Error - error when the owner is an agent while trying to convert an OwnerKey to a GroupKey
- Owner
IsGroup Error - error when the owner is a group while trying to convert an OwnerKey to an AgentKey
- Parcel
Key - represents a Second Life key for a parcel
- Texture
Key - represents a Second Life key for a texture
Enums
- Owner
Key - represents s Second Life key for an owner (e.g. of an object)
Constants
- COMBAT_
LOG_ ID - the key used by the Second Life system to send combat logs to the COMBAT_CHANNEL
- NULL_
KEY - the null key used by Second Life in many places to represent the absence of a key value