Map-related data types
Structs
- Distance
- represents a Second Life distance in meters
- Grid
Coordinate Offset - an offset between two
GridCoordinates - Grid
Coordinates - Grid coordinates for the position of a region on the map
- Grid
Rectangle - represents a rectangle of regions defined by the lower left (minimum coordinates)
and upper right (maximum coordinates) corners in
GridCoordinates - Location
- A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region
- MapTile
Descriptor - describes a map tile
- Region
Coordinates - Region coordinates for the position of something inside a region
- Region
Name - The name of a region
- USBNotecard
- An Universal Sailor Buddy (USB) notecard
- USBWaypoint
- A waypoint in the Universal Sailor Buddy (USB) notecard format
- Unconstrained
Location - A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region, this variant allows out of bounds coordinates (negative and 256 or above for x and y and negative for z)
- Zoom
Level - The map tile zoom level for the Second Life main map
Enums
- Location
Parse Error - the possible errors that can occur when parsing a String to a
Location - Region
Name Error - USBNotecard
Load Error - Errors that can happen when an USB notecard is read from a file
- Zoom
FitError - Errors that can occur when trying to find the correct zoom level to fit regions into an output image of a given size
- Zoom
Level Error - Zoom
Level Parse Error
Traits
- Grid
Coordinates Ext - A trait to allow adding methods to
Vec<GridCoordinates> - Grid
Rectangle Like - represents a grid rectangle like type (usually one that contains a grid rectangle or one that contains a corner and is of a known size