pub struct GridRectangle { /* private fields */ }Expand description
represents a rectangle of regions defined by the lower left (minimum coordinates)
and upper right (maximum coordinates) corners in GridCoordinates
Implementations
Sourceimpl GridRectangle
impl GridRectangle
Sourcepub fn new(corner1: GridCoordinates, corner2: GridCoordinates) -> Self
pub fn new(corner1: GridCoordinates, corner2: GridCoordinates) -> Self
creates a new GridRectangle given any two corners
Sourcepub fn expanded_west(&self, by: u16) -> Self
pub fn expanded_west(&self, by: u16) -> Self
returns a new GridRectangle extended by by regions on the west (-x) side
Saturates at the western edge of the grid (x = 0).
Sourcepub fn expanded_east(&self, by: u16) -> Self
pub fn expanded_east(&self, by: u16) -> Self
returns a new GridRectangle extended by by regions on the east (+x) side
Saturates at the eastern edge of the grid (x = u16::MAX).
Sourcepub fn expanded_south(&self, by: u16) -> Self
pub fn expanded_south(&self, by: u16) -> Self
returns a new GridRectangle extended by by regions on the south (-y) side
Saturates at the southern edge of the grid (y = 0).
Sourcepub fn expanded_north(&self, by: u16) -> Self
pub fn expanded_north(&self, by: u16) -> Self
returns a new GridRectangle extended by by regions on the north (+y) side
Saturates at the northern edge of the grid (y = u16::MAX).