pub struct UnconstrainedLocation {
pub region_name: RegionName,
pub x: i16,
pub y: i16,
pub z: i32,
}Expand description
A location inside Second Life the way it is usually represented in SLURLs or map URLs, based on a Region Name and integer coordinates inside the region, this variant allows out of bounds coordinates (negative and 256 or above for x and y and negative for z)
Fields
region_name: RegionNamethe name of the region of the location
x: i16the x coordinate inside the region
y: i16the y coordinate inside the region
z: i32the z coordinate inside the region
Implementations
Sourceimpl UnconstrainedLocation
impl UnconstrainedLocation
Sourcepub const fn new(region_name: RegionName, x: i16, y: i16, z: i32) -> Self
pub const fn new(region_name: RegionName, x: i16, y: i16, z: i32) -> Self
Creates a new UnconstrainedLocation
Sourcepub const fn region_name(&self) -> &RegionName
pub const fn region_name(&self) -> &RegionName
The region name of this UnconstrainedLocation