ViewerUri

Enum ViewerUri 

pub enum ViewerUri {
Show 90 variants Location(Location), AgentAbout(AgentKey), AgentInspect(AgentKey), AgentInstantMessage(AgentKey), AgentOfferTeleport(AgentKey), AgentPay(AgentKey), AgentRequestFriend(AgentKey), AgentMute(AgentKey), AgentUnmute(AgentKey), AgentCompleteName(AgentKey), AgentDisplayName(AgentKey), AgentUsername(AgentKey), AppearanceShow, BalanceRequest, Chat { channel: ChatChannel, text: String, }, ClassifiedAbout(ClassifiedKey), EventAbout(EventKey), ExperienceProfile(ExperienceKey), GroupAbout(GroupKey), GroupInspect(GroupKey), GroupCreate, GroupListShow, Help { help_query: Option<String>, }, InventorySelect(InventoryKey), InventoryShow, KeyBindingMovementWalkTo, KeyBindingMovementTeleportTo, KeyBindingMovementPushForward, KeyBindingMovementPushBackward, KeyBindingMovementTurnLeft, KeyBindingMovementTurnRight, KeyBindingMovementSlideLeft, KeyBindingMovementSlideRight, KeyBindingMovementJump, KeyBindingMovementPushDown, KeyBindingMovementRunForward, KeyBindingMovementRunBackward, KeyBindingMovementRunLeft, KeyBindingMovementRunRight, KeyBindingMovementToggleRun, KeyBindingMovementToggleFly, KeyBindingMovementToggleSit, KeyBindingMovementStopMoving, KeyBindingCameraLookUp, KeyBindingCameraLookDown, KeyBindingCameraMoveForward, KeyBindingCameraMoveBackward, KeyBindingCameraMoveForwardFast, KeyBindingCameraMoveBackwardFast, KeyBindingCameraSpinOver, KeyBindingCameraSpinUnder, KeyBindingCameraPanUp, KeyBindingCameraPanDown, KeyBindingCameraPanLeft, KeyBindingCameraPanRight, KeyBindingCameraPanIn, KeyBindingCameraPanOut, KeyBindingCameraSpinAroundCounterClockwise, KeyBindingCameraSpinAroundClockwise, KeyBindingCameraMoveForwardSitting, KeyBindingCameraMoveBackwardSitting, KeyBindingCameraSpinOverSitting, KeyBindingCameraSpinUnderSitting, KeyBindingCameraSpinAroundCounterClockwiseSitting, KeyBindingCameraSpinAroundClockwiseSitting, KeyBindingEditingAvatarSpinCounterClockwise, KeyBindingEditingAvatarSpinClockwise, KeyBindingEditingAvatarSpinOver, KeyBindingEditingAvatarSpinUnder, KeyBindingEditingAvatarMoveForward, KeyBindingEditingAvatarMoveBackward, KeyBindingSoundAndMediaTogglePauseMedia, KeyBindingSoundAndMediaToggleEnableMedia, KeyBindingSoundAndMediaVoiceFollowKey, KeyBindingSoundAndMediaToggleVoice, KeyBindingStartChat, KeyBindingStartGesture, KeyBindingScriptTriggerLButton(ScriptTriggerMode), Login { first_name: String, last_name: String, session: String, login_location: Option<String>, }, MapTrackAvatar(FriendKey), ObjectInstantMessage { object_key: ObjectKey, object_name: String, owner: OwnerKey, location: Location, }, OpenFloater(String), Parcel(ParcelKey), Search { category: SearchCategory, search_term: String, }, ShareWithAvatar(AgentKey), Teleport(Location), VoiceCallAvatar(AgentKey), WearFolderByInventoryFolderKey(InventoryFolderKey), WearFolderByLibraryFolderName(String), WorldMap(Location),
}
represents a Viewer URI

Variants



Location(Location)

a link to this location



AgentAbout(AgentKey)

opens the agent profile



AgentInspect(AgentKey)

displays the info dialog for the agent



AgentInstantMessage(AgentKey)

starts an IM session with the agent



AgentOfferTeleport(AgentKey)

displays teleport offer dialog for the agent



AgentPay(AgentKey)

displays pay resident dialog



AgentRequestFriend(AgentKey)

displays friendship offer dialog



AgentMute(AgentKey)

adds agent to block list



AgentUnmute(AgentKey)

removes agent from block list



AgentCompleteName(AgentKey)

replaces the URL with the agent’s display and user names



AgentDisplayName(AgentKey)

replaces the URL with the agent’s display name



AgentUsername(AgentKey)

replaces the URL with the agent’s username



AppearanceShow

show appearance



BalanceRequest

request a L$ balance update from the server



Chat

send a chat message to the given channel, won’t work with DEBUG_CHANNEL

Fields

channel: ChatChannel

the channel to send the message on, can not be DEBUG_CHANNEL

text: String

the text to send



ClassifiedAbout(ClassifiedKey)

open a floater describing the classified ad



EventAbout(EventKey)

open a floater describing the event



ExperienceProfile(ExperienceKey)

open a floater describing the experience



GroupAbout(GroupKey)

open the group profile



GroupInspect(GroupKey)

displays the info dialog for the group



GroupCreate

open the create group dialog



GroupListShow

open the group list to which the current avatar belongs



Help

open help

Fields

help_query: Option<String>

optional help topic



InventorySelect(InventoryKey)

offer inventory



InventoryShow

show inventory



KeyBindingMovementWalkTo

key binding



KeyBindingMovementTeleportTo

key binding



KeyBindingMovementPushForward

key binding



KeyBindingMovementPushBackward

key binding



KeyBindingMovementTurnLeft

key binding



KeyBindingMovementTurnRight

key binding



KeyBindingMovementSlideLeft

key binding



KeyBindingMovementSlideRight

key binding



KeyBindingMovementJump

key binding



KeyBindingMovementPushDown

key binding



KeyBindingMovementRunForward

key binding



KeyBindingMovementRunBackward

key binding



KeyBindingMovementRunLeft

key binding



KeyBindingMovementRunRight

key binding



KeyBindingMovementToggleRun

key binding



KeyBindingMovementToggleFly

key binding



KeyBindingMovementToggleSit

key binding



KeyBindingMovementStopMoving

key binding



KeyBindingCameraLookUp

key binding



KeyBindingCameraLookDown

key binding



KeyBindingCameraMoveForward

key binding



KeyBindingCameraMoveBackward

key binding



KeyBindingCameraMoveForwardFast

key binding



KeyBindingCameraMoveBackwardFast

key binding



KeyBindingCameraSpinOver

key binding



KeyBindingCameraSpinUnder

key binding



KeyBindingCameraPanUp

key binding



KeyBindingCameraPanDown

key binding



KeyBindingCameraPanLeft

key binding



KeyBindingCameraPanRight

key binding



KeyBindingCameraPanIn

key binding



KeyBindingCameraPanOut

key binding



KeyBindingCameraSpinAroundCounterClockwise

key binding



KeyBindingCameraSpinAroundClockwise

key binding



KeyBindingCameraMoveForwardSitting

key binding



KeyBindingCameraMoveBackwardSitting

key binding



KeyBindingCameraSpinOverSitting

key binding



KeyBindingCameraSpinUnderSitting

key binding



KeyBindingCameraSpinAroundCounterClockwiseSitting

key binding



KeyBindingCameraSpinAroundClockwiseSitting

key binding



KeyBindingEditingAvatarSpinCounterClockwise

key binding



KeyBindingEditingAvatarSpinClockwise

key binding



KeyBindingEditingAvatarSpinOver

key binding



KeyBindingEditingAvatarSpinUnder

key binding



KeyBindingEditingAvatarMoveForward

key binding



KeyBindingEditingAvatarMoveBackward

key binding



KeyBindingSoundAndMediaTogglePauseMedia

key binding



KeyBindingSoundAndMediaToggleEnableMedia

key binding



KeyBindingSoundAndMediaVoiceFollowKey

key binding



KeyBindingSoundAndMediaToggleVoice

key binding



KeyBindingStartChat

key binding



KeyBindingStartGesture

key binding



KeyBindingScriptTriggerLButton(ScriptTriggerMode)

key binding



Login

login on launch

Fields

first_name: String

account first name

last_name: String

account last name

session: String

secure session id

login_location: Option<String>

login location



MapTrackAvatar(FriendKey)

track a friend with the permission on the world map



ObjectInstantMessage

display an info dialog for the object sending this message

Fields

object_key: ObjectKey

key of the object

object_name: String

name of the object

owner: OwnerKey

owner of the object

location: Location

object location



OpenFloater(String)

open the named floater



Parcel(ParcelKey)

open a floater describing a parcel



Search

open a search floater with matching results

Fields

category: SearchCategory

search category

search_term: String

search term



ShareWithAvatar(AgentKey)

open an inventory share/IM window for agent



Teleport(Location)

teleport to this location



VoiceCallAvatar(AgentKey)

start a private voice session with this avatar



WearFolderByInventoryFolderKey(InventoryFolderKey)

replace outfit with contents of folder specified by key (UUID)



WearFolderByLibraryFolderName(String)

replace outfit with contents of named library folder



WorldMap(Location)

open the world map with this destination selected

Implementations

Source

impl ViewerUri

pub const fn is_location(&self) -> bool

Returns true if the enum is ViewerUri::Location otherwise false

pub const fn is_agent_about(&self) -> bool

Returns true if the enum is ViewerUri::AgentAbout otherwise false

pub const fn is_agent_inspect(&self) -> bool

Returns true if the enum is ViewerUri::AgentInspect otherwise false

pub const fn is_agent_instant_message(&self) -> bool

Returns true if the enum is ViewerUri::AgentInstantMessage otherwise false

pub const fn is_agent_offer_teleport(&self) -> bool

Returns true if the enum is ViewerUri::AgentOfferTeleport otherwise false

pub const fn is_agent_pay(&self) -> bool

Returns true if the enum is ViewerUri::AgentPay otherwise false

pub const fn is_agent_request_friend(&self) -> bool

Returns true if the enum is ViewerUri::AgentRequestFriend otherwise false

pub const fn is_agent_mute(&self) -> bool

Returns true if the enum is ViewerUri::AgentMute otherwise false

pub const fn is_agent_unmute(&self) -> bool

Returns true if the enum is ViewerUri::AgentUnmute otherwise false

pub const fn is_agent_complete_name(&self) -> bool

Returns true if the enum is ViewerUri::AgentCompleteName otherwise false

pub const fn is_agent_display_name(&self) -> bool

Returns true if the enum is ViewerUri::AgentDisplayName otherwise false

pub const fn is_agent_username(&self) -> bool

Returns true if the enum is ViewerUri::AgentUsername otherwise false

pub const fn is_appearance_show(&self) -> bool

Returns true if the enum is ViewerUri::AppearanceShow otherwise false

pub const fn is_balance_request(&self) -> bool

Returns true if the enum is ViewerUri::BalanceRequest otherwise false

pub const fn is_chat(&self) -> bool

Returns true if the enum is ViewerUri::Chat otherwise false

pub const fn is_classified_about(&self) -> bool

Returns true if the enum is ViewerUri::ClassifiedAbout otherwise false

pub const fn is_event_about(&self) -> bool

Returns true if the enum is ViewerUri::EventAbout otherwise false

pub const fn is_experience_profile(&self) -> bool

Returns true if the enum is ViewerUri::ExperienceProfile otherwise false

pub const fn is_group_about(&self) -> bool

Returns true if the enum is ViewerUri::GroupAbout otherwise false

pub const fn is_group_inspect(&self) -> bool

Returns true if the enum is ViewerUri::GroupInspect otherwise false

pub const fn is_group_create(&self) -> bool

Returns true if the enum is ViewerUri::GroupCreate otherwise false

pub const fn is_group_list_show(&self) -> bool

Returns true if the enum is ViewerUri::GroupListShow otherwise false

pub const fn is_help(&self) -> bool

Returns true if the enum is ViewerUri::Help otherwise false

pub const fn is_inventory_select(&self) -> bool

Returns true if the enum is ViewerUri::InventorySelect otherwise false

pub const fn is_inventory_show(&self) -> bool

Returns true if the enum is ViewerUri::InventoryShow otherwise false

pub const fn is_key_binding_movement_walk_to(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementWalkTo otherwise false

pub const fn is_key_binding_movement_teleport_to(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementTeleportTo otherwise false

pub const fn is_key_binding_movement_push_forward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementPushForward otherwise false

pub const fn is_key_binding_movement_push_backward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementPushBackward otherwise false

pub const fn is_key_binding_movement_turn_left(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementTurnLeft otherwise false

pub const fn is_key_binding_movement_turn_right(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementTurnRight otherwise false

pub const fn is_key_binding_movement_slide_left(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementSlideLeft otherwise false

pub const fn is_key_binding_movement_slide_right(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementSlideRight otherwise false

pub const fn is_key_binding_movement_jump(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementJump otherwise false

pub const fn is_key_binding_movement_push_down(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementPushDown otherwise false

pub const fn is_key_binding_movement_run_forward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementRunForward otherwise false

pub const fn is_key_binding_movement_run_backward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementRunBackward otherwise false

pub const fn is_key_binding_movement_run_left(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementRunLeft otherwise false

pub const fn is_key_binding_movement_run_right(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementRunRight otherwise false

pub const fn is_key_binding_movement_toggle_run(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementToggleRun otherwise false

pub const fn is_key_binding_movement_toggle_fly(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementToggleFly otherwise false

pub const fn is_key_binding_movement_toggle_sit(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementToggleSit otherwise false

pub const fn is_key_binding_movement_stop_moving(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingMovementStopMoving otherwise false

pub const fn is_key_binding_camera_look_up(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraLookUp otherwise false

pub const fn is_key_binding_camera_look_down(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraLookDown otherwise false

pub const fn is_key_binding_camera_move_forward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraMoveForward otherwise false

pub const fn is_key_binding_camera_move_backward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraMoveBackward otherwise false

pub const fn is_key_binding_camera_move_forward_fast(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraMoveForwardFast otherwise false

pub const fn is_key_binding_camera_move_backward_fast(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraMoveBackwardFast otherwise false

pub const fn is_key_binding_camera_spin_over(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraSpinOver otherwise false

pub const fn is_key_binding_camera_spin_under(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraSpinUnder otherwise false

pub const fn is_key_binding_camera_pan_up(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraPanUp otherwise false

pub const fn is_key_binding_camera_pan_down(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraPanDown otherwise false

pub const fn is_key_binding_camera_pan_left(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraPanLeft otherwise false

pub const fn is_key_binding_camera_pan_right(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraPanRight otherwise false

pub const fn is_key_binding_camera_pan_in(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraPanIn otherwise false

pub const fn is_key_binding_camera_pan_out(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraPanOut otherwise false

pub const fn is_key_binding_camera_spin_around_counter_clockwise(&self) -> bool

pub const fn is_key_binding_camera_spin_around_clockwise(&self) -> bool

pub const fn is_key_binding_camera_move_forward_sitting(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraMoveForwardSitting otherwise false

pub const fn is_key_binding_camera_move_backward_sitting(&self) -> bool

pub const fn is_key_binding_camera_spin_over_sitting(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraSpinOverSitting otherwise false

pub const fn is_key_binding_camera_spin_under_sitting(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingCameraSpinUnderSitting otherwise false

pub const fn is_key_binding_camera_spin_around_counter_clockwise_sitting( &self, ) -> bool

pub const fn is_key_binding_camera_spin_around_clockwise_sitting(&self) -> bool

pub const fn is_key_binding_editing_avatar_spin_counter_clockwise(&self) -> bool

pub const fn is_key_binding_editing_avatar_spin_clockwise(&self) -> bool

pub const fn is_key_binding_editing_avatar_spin_over(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingEditingAvatarSpinOver otherwise false

pub const fn is_key_binding_editing_avatar_spin_under(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingEditingAvatarSpinUnder otherwise false

pub const fn is_key_binding_editing_avatar_move_forward(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingEditingAvatarMoveForward otherwise false

pub const fn is_key_binding_editing_avatar_move_backward(&self) -> bool

pub const fn is_key_binding_sound_and_media_toggle_pause_media(&self) -> bool

pub const fn is_key_binding_sound_and_media_toggle_enable_media(&self) -> bool

pub const fn is_key_binding_sound_and_media_voice_follow_key(&self) -> bool

pub const fn is_key_binding_sound_and_media_toggle_voice(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingSoundAndMediaToggleVoice otherwise false

pub const fn is_key_binding_start_chat(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingStartChat otherwise false

pub const fn is_key_binding_start_gesture(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingStartGesture otherwise false

pub const fn is_key_binding_script_trigger_l_button(&self) -> bool

Returns true if the enum is ViewerUri::KeyBindingScriptTriggerLButton otherwise false

pub const fn is_login(&self) -> bool

Returns true if the enum is ViewerUri::Login otherwise false

pub const fn is_map_track_avatar(&self) -> bool

Returns true if the enum is ViewerUri::MapTrackAvatar otherwise false

pub const fn is_object_instant_message(&self) -> bool

Returns true if the enum is ViewerUri::ObjectInstantMessage otherwise false

pub const fn is_open_floater(&self) -> bool

Returns true if the enum is ViewerUri::OpenFloater otherwise false

pub const fn is_parcel(&self) -> bool

Returns true if the enum is ViewerUri::Parcel otherwise false

Returns true if the enum is ViewerUri::Search otherwise false

pub const fn is_share_with_avatar(&self) -> bool

Returns true if the enum is ViewerUri::ShareWithAvatar otherwise false

pub const fn is_teleport(&self) -> bool

Returns true if the enum is ViewerUri::Teleport otherwise false

pub const fn is_voice_call_avatar(&self) -> bool

Returns true if the enum is ViewerUri::VoiceCallAvatar otherwise false

pub const fn is_wear_folder_by_inventory_folder_key(&self) -> bool

Returns true if the enum is ViewerUri::WearFolderByInventoryFolderKey otherwise false

pub const fn is_wear_folder_by_library_folder_name(&self) -> bool

Returns true if the enum is ViewerUri::WearFolderByLibraryFolderName otherwise false

pub const fn is_world_map(&self) -> bool

Returns true if the enum is ViewerUri::WorldMap otherwise false

Source

impl ViewerUri

pub const fn internal_only(&self) -> bool

this returns whether the given ViewerUri can only be called from internal browsers/chat/… or if external programs (like browsers) can use them too